@@ -5,7 +5,6 @@ from django.db import models, transaction, connection
 from django.conf.urls import url
 from django.contrib import admin, messages
 from django.contrib.admin import options
-from django.contrib.admin.models import LogEntry
 from django.contrib.admin.utils import unquote, quote
 try:
     from django.contrib.contenttypes.admin import GenericInlineModelAdmin
@@ -86,7 +85,7 @@ class VersionAdmin(admin.ModelAdmin):
             # could first call super() and get the change_message from the returned
             # LogEntry.
             if isinstance(change_message, list):
-                set_comment(LogEntry(change_message=json.dumps(change_message)).get_change_message())
+                set_comment(json.dumps(change_message))
             else:
                 set_comment(change_message)
         try:
@@ -97,7 +96,7 @@ class VersionAdmin(admin.ModelAdmin):
     def log_change(self, request, object, message):
         if is_active():
             if isinstance(message, list):
-                set_comment(LogEntry(change_message=json.dumps(message)).get_change_message())
+                set_comment(json.dumps(message))
             else:
                 set_comment(message)
         super(VersionAdmin, self).log_change(request, object, message)
