@@ -1,12 +1,13 @@
 from __future__ import unicode_literals
 from collections import defaultdict
-from itertools import chain
+from itertools import chain, groupby
 from django.contrib.contenttypes.models import ContentType
 try:
     from django.contrib.contenttypes.fields import GenericForeignKey
 except ImportError:  # Django < 1.9 pragma: no cover
     from django.contrib.contenttypes.generic import GenericForeignKey
 from django.conf import settings
+from django.contrib.admin.models import LogEntry
 from django.core import serializers
 from django.core.serializers.base import DeserializationError
 from django.core.exceptions import ObjectDoesNotExist
@@ -62,6 +63,14 @@ class Revision(models.Model):
         help_text="A text comment on this revision.",
     )
 
+    def get_comment(self):
+        try:
+            return LogEntry(change_message=self.comment).get_change_message()
+        except AttributeError:
+            # Django < 1.10
+            # LogEntry dont have `.get_change_message()`
+            return self.comment
+
     def revert(self, delete=False):
         # Group the models by the database of the serialized model.
         versions_by_db = defaultdict(list)
@@ -88,7 +97,10 @@ class Revision(models.Model):
                     )
                     # Delete objects that are no longer in the current revision.
                     collector = Collector(using=version_db)
-                    collector.collect([item for item in current_revision if item not in old_revision])
+                    new_objs = [item for item in current_revision
+                                if item not in old_revision]
+                    for model, group in groupby(new_objs, type):
+                        collector.collect(list(group))
                     collector.delete()
                 # Attempt to revert all revisions.
                 _safe_revert(versions)
